var servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XColumnsSupplier", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a92868318efdc74df5cf74c939aa50e9b", null ],
    [ "XDataDescriptorFactory", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a165621d8c4d1f58bd9578b5afb525aac", null ],
    [ "Catalog", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a93c5cd015ea94a5e7423c31fe6b4ffbd", null ],
    [ "IsClustered", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a37ae95e57dd7097d2aca243a07132e0c", null ],
    [ "IsPrimaryKeyIndex", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a8b74f071348ddd52c9350a62fa95c9c8", null ],
    [ "IsUnique", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#ade66a9a989aedc6f0d08dbc9230a1818", null ],
    [ "Name", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Index.html#a7ee9065718e6628dc7791b756fa6c0f9", null ]
];